@@ -1,15 +1,9 @@
 import inspect
-import sys
 import types
-from typing import TypeVar
+from typing import Callable, Tuple, TypeVar
 
 from .func import asyncify_func
 
-if sys.version_info >= (3, 10):
-    from collections.abc import Callable
-else:
-    from typing import Callable
-
 
 __all__ = (
     'asyncify_class',
@@ -21,7 +15,7 @@ CallableT = TypeVar('CallableT', bound=Callable)
 TypeT = TypeVar('TypeT', bound=type)
 
 
-function_types: tuple[type, ...] = (
+function_types: Tuple[type, ...] = (
     types.FunctionType,
     classmethod,
     staticmethod
@@ -54,7 +48,7 @@ def asyncify_class(cls: TypeT) -> TypeT:
             def __init__(self):  # ignored by asyncify
                 self.session = requests.Session()
 
-            def request(self, method: str, url: str):  # now a coroutine function
+            def request(self, method, url):  # now a coroutine function
                 return self.session.request(method, url)
 
         # can also be used like this
